Enum lru_time_cache::Entry [] [src]

pub enum Entry<'a, K: 'a, V: 'a> {
    Vacant(VacantEntry<'a, K, V>),
    Occupied(OccupiedEntry<'a, V>),
}

A view into a single entry in a lru_cache, which may either be vacant or occupied.

Variants

Vacant(VacantEntry<'a, K, V>)

A vacant Entry

Occupied(OccupiedEntry<'a, V>)

An occupied Entry

Methods

impl<'a, K: PartialOrd + Ord + Clone, V: Clone> Entry<'a, K, V>
[src]

fn or_insert(self, default: V) -> &'a mut V

Ensures a value is in the entry by inserting the default if empty, and returns a mutable reference to the value in the entry.

fn or_insert_with<F: FnOnce() -> V>(self, default: F) -> &'a mut V

Ensures a value is in the entry by inserting the result of the default function if empty, and returns a mutable reference to the value in the entry.